pub enum CharsetError {
NoSyntaxIdentifier,
Unsupported {
syntax_identifier: String,
},
InvalidBytes {
syntax_identifier: String,
offset: usize,
},
Unrepresentable {
syntax_identifier: String,
character: char,
position: usize,
},
}Expand description
Why an interchange could not be decoded or encoded.
Variants
NoSyntaxIdentifier
The input has no UNB segment with a syntax identifier.
Unsupported
A syntax identifier this crate has no character set for.
InvalidBytes
A byte sequence that is not valid in the declared character set.
Unrepresentable
A character the declared character set cannot represent.